/******************************************************************************
*
*       Copyright (C) 2004 Freescale, Inc.
*       All Rights Reserved
*
* Filename:     $RCSfile: main.c,v $
* Author:       $Author: r29541 $
* Locker:       $Locker: r29541 $
* State:        $State: Exp $
* Revision:     $Revision: 1.2 $
*
* Functions:    
*
* History:   1.1  Released on web
*            1.2  Bug fixes
*            1.3  Jan 05 Added BAUD Command , added Verbose mode  
*
*
* Description:   This is the main file for the Tango3 Monitor program 
*                           
*   
*
* Notes:        
*
******************************************************************************/
#include <hidef.h>              /* for DisableInterrupts macro */
#include "MC9S08RG60.h"         /* include peripheral declarations */
#include <stdio.h>
#include <stdlib.h>



/*************** Function Prototypes *****************************************/
void SCI1Setup(unsigned char BaudRate);
void SCI1Rx(void);
void TransmitMessage(char *Message);
void DisplayStatus(void);
void DisplayHelp(void);
void SendMessage(void);
void EchoByte(char *Message);


/***************  #defines to link mcu pins to Tango ic pins  ****************/
#define TANGO_DATA          PTBD_PTBD7
#define TANGO_DATA_DDR      PTBDD_PTBDD7

#define TANGO_ENABLE        PTCD_PTCD1              
#define TANGO_ENABLE_DDR    PTCDD_PTCDD1           

#define TANGO_MODE          PTED_PTED0              
#define TANGO_MODE_DDR      PTEDD_PTEDD0           

#define TANGO_ENABLE_PA     PTED_PTED1              
#define TANGO_ENABLE_PA_DDR  PTEDD_PTEDD1           


/*************** #defines for timer module on mcu  ***************************/

#define TIMER_ADDRESS     0x30            /* Location of 1st timer register  */
#define TIMER_CHANNEL     1               /* Define which timer channel to use*/
#define TIMER_CLOCK_SPEED  8000000            
#define TIMER_PRESCALE    1               /* Specify timer prescaler value   */
 		                                      /* NOTE: If using DATACLK from     */
 		                                      /* Tango,prescaler will be forced  */
 		                                      /* to 1                            */
                                          /* Note:timer channels start from 0*/

#define TIMER_CLOCK_SOURCE    1	          /* Use to set clock source for tmr */
                                          /* 1 = Bus clock                   */
                                          /* 2 = XCLK- not all mcus have XCLK*/                            
                                          /* 3 = Ext clock                   */



/************* Timer register offsets  **************************************/
/***** Register address offsets for normal S08 timer ************************/
#define TPMxSC  	*(volatile unsigned char *)(TIMER_ADDRESS+0) /* Tmr status/ctrl reg*/
#define TPMxCNTH	*(volatile unsigned char *)(TIMER_ADDRESS+1) /* Timer counter H	*/
#define TPMxCNTL	*(volatile unsigned char *)(TIMER_ADDRESS+2) /* Timer counter L	*/
#define TPMxMODH	*(volatile unsigned char *)(TIMER_ADDRESS+3) /* Timer modulus H	*/
#define TPMxMODL	*(volatile unsigned char *)(TIMER_ADDRESS+4) /* Timer modulus L	*/

/* Registers for each timer channel */
#define TPMxCxSC	*(volatile unsigned char *)(TIMER_ADDRESS+5+(3*TIMER_CHANNEL)+0)
#define TPMxCxVH	*(volatile unsigned char *)(TIMER_ADDRESS+5+(3*TIMER_CHANNEL)+1)
#define TPMxCxVL	*(volatile unsigned char *)(TIMER_ADDRESS+5+(3*TIMER_CHANNEL)+2)


#define TIMER_ON 	(TIMER_CLOCK_SOURCE*8)            /* OR this value to timer control */
                                                    /* reg to enable clock            */
								                                    /* NOTE, cannot be used to switch */
								                                    /* from clock to clock            */


#define TIMER_OFF		0xE7   /* AND this value to timer ctrl reg to disable clock */

#define CHnF 0x80



/************** Global variables *********************************************/
unsigned char  Data, Mode, Enable, Band, Pa;   /* These variables hold values of each pin */
unsigned int DataRate ;

#define NULL_STRING '\0'                        /* Null at end of strings */
#define MSG_LENGTH 200
#define COMMAND_LENGTH  12
#define DATA_LENGTH MSG_LENGTH-COMMAND_LENGTH

    
char  Message[MSG_LENGTH];						/* Array to hold incoming messages from SCI */
char * Message_Pointer = Message;
    
char CommandBuffer[COMMAND_LENGTH];            /* Array to hold command stripped from message */
char DataBuffer[DATA_LENGTH];                  /* Array to hold data stripped from message */
char * ptrData;
 
 
 
unsigned int TimerModulus;                      /* Variable to hold bit times for generating */
                                                /* Manchester encoded bits on timer output pin*/
unsigned char ModH;
unsigned char ModL;
unsigned char ComH;
unsigned char ComL;

unsigned int Com1;
unsigned int Com0;

unsigned char Com0H,Com0L,Com1H, Com1L;

#define VERBOSE_ON  1
#define VERBOSE_OFF 0

unsigned char VerboseMode = VERBOSE_ON;



#define  BAUD_9600  52
#define  BAUD_19200 26
#define  BAUD_38400 13






/*
 ** SendMessage
 *
 *  FILENAME: 
 *
 *  PARAMETERS:
 *
 *  DESCRIPTION: Generates Manchester encoded messagea on timer output pin   
 *
 *  RETURNS:
 *
 */
void SendMessage(void)
{
    TimerModulus = (unsigned int)((TIMER_CLOCK_SPEED/DataRate)/TIMER_PRESCALE);

    ModH = (unsigned char)(TimerModulus/256);
    ModL = (unsigned char)(TimerModulus); 

    ComH = (unsigned char)((TimerModulus/2)/256);
    ComL = (unsigned char)(TimerModulus/2);

    TPMxMODH = ModH;            /* Set timebase (data rate may have been changed by user) */
    TPMxMODL = ModL;

    TPMxSC = TPMxSC & TIMER_OFF; /*Turn off timer  */
    TPMxCNTL = 0;                /* Reset timer counter */
   
    ptrData = DataBuffer; 

  
    while ( (*ptrData != NULL_STRING) && (*ptrData != '\r') )
    {
        switch (*ptrData++)
    	{

    		case 'P':	  	                       
       		            if (TANGO_MODE == 1)                /* if FSK, send 4 0's */
    		            { 
    		                TPMxCxVH = ComH;
			                TPMxCxVL = ComL;		        /* Set O/C to 1/2 modulus               */
  							TPMxCxSC = 0x24;		            /* PWM , low true pulses        */
         							                            /* ( _|-  Manchester output )   */
                            TPMxSC = TPMxSC | TIMER_ON;         /* Start timer */		

    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 
 
   							TPMxCxSC = 0x24;		            /* PWM , low true pulses        */
         							                            /* ( _|-  Manchester output )   */
    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 
 
   							TPMxCxSC = 0x24;		            /* PWM , low true pulses        */
         							                            /* ( _|-  Manchester output )   */
    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 
 
   							TPMxCxSC = 0x24;		            /* PWM , low true pulses        */
         							                            /* ( _|-  Manchester output )   */
    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 
    		            }
    		            else                                    /* if OOK, send Preamble shape*/
    		            {
			                TPMxCxSC = 0x1c;				    /* O/C, set on compare                  */
    		                TPMxCxVH = ModH;
			                TPMxCxVL = ModL;		            /* Set O/C to = MOD */
                            TPMxSC = TPMxSC | TIMER_ON;         /* Start timer */		

    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 

    						TPMxCxSC = 0x1c;				    /* Clears ch flag          */
    						TPMxCxVH = ComH;
    						TPMxCxVL = ComL;		            /* Set O/C to 1/2 modulus   */

    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 

    						TPMxCxSC = 0x1c;				    /* Clears ch flag */
    						TPMxCxVH = ComH;
    						TPMxCxVL = ComL;		            /* Set O/C to 1/2 modulus   */

    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 

    						TPMxCxVH = ComH;
    						TPMxCxVL = ComL;		            /* Set O/C to 1/2 modulus   */
    						TPMxCxSC = 0x24;		            /* PWM , low true pulses    */
    						                                    /*( _|-  Manchester output )*/
    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 
                        }
                        break;      
                        

    		case '0':				
    		                TPMxCxVH = ComH;
			                TPMxCxVL = ComL;		            /* Set O/C to 1/2 modulus               */
    						TPMxCxSC = 0x24;		            /* PWM , low true pulses        */
                            TPMxSC = TPMxSC | TIMER_ON;         /* Start timer */		
    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 
         							                            /* ( _|-  Manchester output )   */
                            break;
                            
            case '1':                
    		                TPMxCxVH = ComH;
			                TPMxCxVL = ComL;		            /* Set O/C to 1/2 modulus               */
    						TPMxCxSC = 0x28;		            /* PWM, high true pulses        */
                            TPMxSC = TPMxSC | TIMER_ON;         /* Start timer */		
    							                                /* (-|_  Manchester output)     */
       						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 
						    break;
            
            case 'L':
                            TPMxCxSC = 0x18;			        /* O/C , clear on match */
						    TPMxCxVH = ModH; 
						    TPMxCxVL = ModL;	                /* Set compare to == modulus    */
                            TPMxSC = TPMxSC | TIMER_ON;         /* Start timer */		

    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 

                            TPMxCxSC = 0x18;			        /* O/C , clear on match */
						    TPMxCxVH = ComH; 
						    TPMxCxVL = ComL;	                /* Set compare to 1/2 modulus    */
  						
    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 
                            break;
                            
 
            case 'H':
			                TPMxCxSC = 0x1c;				    /* O/C, set on compare                  */
    		                TPMxCxVH = ModH;
			                TPMxCxVL = ModL;		            /* Set O/C to = MOD */
                            TPMxSC = TPMxSC | TIMER_ON;         /* Start timer */		

    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 

			                TPMxCxSC = 0x1c;				    /* O/C, set on compare                  */
						    TPMxCxVH = ComH; 
						    TPMxCxVL = ComL;	                /* Set compare to 1/2 modulus    */
  						
    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 
                            break;
            
            
                              
 
    		case  'E' :	
    						TPMxCxSC = 0x18;			        /* O/C , clear on match */
						    TPMxCxVH = ModH; 
						    TPMxCxVL = ModL;	                /* Set compare to == modulus    */
                            TPMxSC = TPMxSC | TIMER_ON;         /* Start timer */		
    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 
						    
                            TPMxCxSC = 0x18;			        /* O/C , clear on match */
						    TPMxCxVH = ModH; 
						    TPMxCxVL = ModL;	                /* Set compare to == modulus    */
                            TPMxSC = TPMxSC | TIMER_ON;         /* Start timer */		
						
    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 

                            
                            TPMxCxSC = 0x18;			        /* O/C , clear on match */
						    TPMxCxVH = ComH; 
						    TPMxCxVL = ComL;	                /* Set compare to 1/2 modulus    */
    						
    						while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 

    						break;
    			
    		default:		break;
    	}
    }
        TPMxCxSC = 0x18;			        /* O/C , clear on match */


    TPMxSC = TPMxSC | TIMER_ON;         /* Start timer  */		
        
    TPMxCxVH = ModH;
    TPMxCxVL = ModL;	                /* Set compare to == modulus    */

    while ( (TPMxCxSC & CHnF) == 0){}   /* wait until ch flag set */ 

    TPMxSC = TPMxSC & TIMER_OFF; /*Turn off timer  */
    TPMxCNTL = 0;                /* Reset timer counter */

    TANGO_DATA = 0;
    TANGO_DATA_DDR = 1;
    Data = 0;


}                       
        

/*
 ** SCI1Setup
 *
 *  FILENAME: 
 *
 *  PARAMETERS:
 *
 *  DESCRIPTION: Setup SCI1 for 9600, no parity, 1 stop bit  
 *
 *  RETURNS:
 *
 */
void SCI1Setup(unsigned char BaudRate)
	{
	SCIC2  = 0;		/* Disable sci1 */
	SCIBDH = 0;		/* Set baud rate to 9600 */
	SCIBDL = BaudRate;
	
	SCIC1 = 0;		/* 8 bits, 1 start, 1 stop, no parity */
	SCIC2_TE = 1;	    /* Enable tx */
	SCIC2_RE = 1;	    /* Enable rx */
	}





/*
 ** SCI1Rx
 *
 *  FILENAME: 
 *
 *  PARAMETERS:
 *
 *  DESCRIPTION: Process message received on SCI
 *
 *  RETURNS:
 *
 */
void SCI1Rx(void)
{
    int temp;
    unsigned long squarewave;

	*Message_Pointer =  SCIS1;		                    /* Read reg to clear rdrf flag */
	*Message_Pointer =  SCIDRL;                         /* Read input                  */
	*Message_Pointer = toupper(*Message_Pointer);		/* Convert to upper case       */

	if (Message_Pointer == &Message[MSG_LENGTH-1])	    /* If at the end of the array, */
		Message_Pointer = Message;						/* go back to the start of array */
							  
	if (*Message_Pointer != '\r')  						/* If character is not C/R	    */
	{
		EchoByte(Message_Pointer);			   			/* Echo char to terminal and   */
		Message_Pointer++;					  			/* move pointer                */
	}
	else												/* If char is C/R              */
	{
		EchoByte(Message_Pointer);						/* Echo C/R then                */
		*Message_Pointer = NULL_STRING;					/* Terminate message with a NULL_STRING */
		Message_Pointer = Message;						/* Reset pointer to start of message    */
		TransmitMessage("\n\r");						/* Go to new line                       */

        sscanf(Message, "%s %s" ,CommandBuffer, DataBuffer); /* Read command and data */

        if (0 == strcmp(CommandBuffer, "HELP"))
        {
            DisplayHelp();
            Message_Pointer = Message;
            strcpy(CommandBuffer,"STATUS"); 
        }             
        else if (0 == strcmp(CommandBuffer, "STATUS"))
        {
            DisplayStatus();
            TransmitMessage("OK\n\r");
        }
        else if (0 == strcmp(CommandBuffer, "DATA"))
        {
            if (*DataBuffer =='1')
            {
                TANGO_DATA = 1;
                TANGO_DATA_DDR = 1;
                Data = 1;
                DisplayStatus();
                TransmitMessage("OK\n\r");
            }
            else  if (*DataBuffer =='0')
            {
                TANGO_DATA = 0;
                TANGO_DATA_DDR = 1;
                Data = 0;
                DisplayStatus();
                TransmitMessage("OK\n\r");
            }
            else  if (*DataBuffer =='Z')
            {
                TANGO_DATA = 0;
                TANGO_DATA_DDR = 0;
                Data = 2;
                DisplayStatus();
                TransmitMessage("OK\n\r");
            }
            else  
            {
                TransmitMessage("Incorrect value.  \n\r");
                Message_Pointer = Message;
                strcpy(CommandBuffer,"STATUS"); 
            }
        }
        else  if (0 == strcmp(CommandBuffer, "MODE"))
        {
            if (*DataBuffer =='1')
            {
                TANGO_MODE = 1;
                TANGO_MODE_DDR = 1;
                Mode = 1;
                DisplayStatus();
                TransmitMessage("OK\n\r");
            }
            else  if (*DataBuffer =='0')
            {
                TANGO_MODE = 0;
                TANGO_MODE_DDR = 1;
                Mode = 0;
                DisplayStatus();
                TransmitMessage("OK\n\r");
            }
             else  if (*DataBuffer =='Z')
            {
                TANGO_MODE = 0;
                TANGO_MODE_DDR = 0;
                Mode = 2;
                DisplayStatus();
                TransmitMessage("OK\n\r");
            }

            else  
            {
                TransmitMessage("Incorrect value.  \n\r");
                Message_Pointer = Message;
                strcpy(CommandBuffer,"STATUS"); 
            }
        }
        else  if (0 == strcmp(CommandBuffer, "ENABLE"))
        {
            if (*DataBuffer =='1')
            {
                TANGO_ENABLE = 1;
                TANGO_ENABLE_DDR = 1;
                Enable = 1;
                DisplayStatus();
                TransmitMessage("OK\n\r");
            }
            else  if (*DataBuffer =='0')
            {
                TANGO_ENABLE = 0;
                TANGO_ENABLE_DDR = 1;
                Enable = 0;
                DisplayStatus();
                TransmitMessage("OK\n\r");
            }
             else  if (*DataBuffer =='Z')
            {
                TANGO_ENABLE = 0;
                TANGO_ENABLE_DDR = 0;
                Enable = 2;
                DisplayStatus();
                TransmitMessage("OK\n\r");
            }
           else  
            {
                TransmitMessage("Incorrect value.  \n\r");
                Message_Pointer = Message;
                strcpy(CommandBuffer,"STATUS"); 
            }
        }
        else  if (0 == strcmp(CommandBuffer, "PA"))
        {
           if (*DataBuffer =='1')
            {
                TANGO_ENABLE_PA = 1;
                TANGO_ENABLE_PA_DDR = 1;
                Pa = 1;
                DisplayStatus();
                TransmitMessage("OK\n\r");
            }
            else  if (*DataBuffer =='0')
            {
                TANGO_ENABLE_PA = 0;
                TANGO_ENABLE_PA_DDR = 1;
                Pa = 0;
                DisplayStatus();
                TransmitMessage("OK\n\r");
            }
            else  if (*DataBuffer =='Z')
            {
                TANGO_ENABLE_PA = 0;
                TANGO_ENABLE_PA_DDR = 0;
                Pa = 2;
                DisplayStatus();
                TransmitMessage("OK\n\r");
            }
            else  
            {
                TransmitMessage("Incorrect value.  \n\r");
                Message_Pointer = Message;
                strcpy(CommandBuffer,"STATUS"); 
            }
        }
        else  if (0 == strcmp(CommandBuffer, "DATARATE"))
        {

                temp = atoi(&DataBuffer);
                if ( (temp >= 500) && (temp <= 10600))
                {
                    DataRate = temp;
                    DisplayStatus();
                    TransmitMessage("OK\n\r");
                }
                else
                {
                    TransmitMessage("Incorrect value.  \n\r");
                    Message_Pointer = Message;
                    strcpy(CommandBuffer,"STATUS"); 
                }
                
        }
        else if (0 == strcmp(CommandBuffer, "SEND"))
        {
            SendMessage();
            DisplayStatus();
            TransmitMessage("OK\n\r");
        }
        else if (0 == strcmp(CommandBuffer, "BAUD"))
        {
          if (0 == strcmp(DataBuffer, "9600"))
          {
              SCI1Setup(BAUD_9600);
          }
          else if (0 == strcmp(DataBuffer, "19200"))
          {
              SCI1Setup(BAUD_19200);
          }
          else if (0 == strcmp(DataBuffer, "38400"))
          {
              SCI1Setup(BAUD_38400);
          }
          else
          {
            TransmitMessage("Incorrect value.  \n\r");
          }
        Message_Pointer = Message;
        strcpy(CommandBuffer,"STATUS"); 
        }
        else if (0 == strcmp(CommandBuffer, "VERBOSE"))
        {
          if (0 == strcmp(DataBuffer, "ON"))
          {
              VerboseMode = VERBOSE_ON;
              DisplayStatus();
              TransmitMessage("OK\n\r");

          }
          else if (0 == strcmp(DataBuffer, "OFF"))
          {
              VerboseMode = VERBOSE_OFF;
              DisplayStatus();
              TransmitMessage("OK\n\r");
          }
          else
          {
            DisplayStatus();
            TransmitMessage("Incorrect command\n\r");
            Message_Pointer = Message;
            strcpy(CommandBuffer,"STATUS"); 
          }
        Message_Pointer = Message;
        strcpy(CommandBuffer,"STATUS"); 
        }
 
        else  if (0 == strcmp(CommandBuffer, "TXSQUARE"))
        {
                 squarewave = strtol(DataBuffer,NULL,10);   /* Read number in DECIMAL format */
                 if ( (squarewave<= 8191) && (squarewave >=0)) 
                 {

                    squarewave = squarewave * 8;                      /* convert to us */
                    TPMxMODH = (unsigned char)(squarewave >> 8);
                    TPMxMODL = (unsigned char)(squarewave);
                 
                    TPMxCxVH = (unsigned char)(squarewave >> 9); 
                    TPMxCxVL = (unsigned char)(squarewave >> 1);
                    
                    TPMxCxSC = 0x24;  //Set to PWM mode
                    
                    TPMxSC = 0x08;    //Go timer
                 
                 
                    TransmitMessage("Sending square wave. Press return to stop \n\r");
                    strcpy(CommandBuffer,"TXSQUAREOFF"); 

                 }
                 else  
                 {
                    TransmitMessage("Incorrect value\n\n\r");
                    Message_Pointer = Message;
                    strcpy(CommandBuffer,"STATUS"); 
                 }
 				 }
 
        

        else  if (0 == strcmp(CommandBuffer, "TXSQUAREOFF")) 
        {

                TPMxSC = 0x00;    //Timer off


                DisplayStatus();
                TransmitMessage("Stopped transmission\n\r");

        }

        
        else if (0 == strcmp(CommandBuffer, ""))
        {
            DisplayStatus();
            TransmitMessage("OK\n\r");
        }
        else  
        {
            DisplayStatus();
            TransmitMessage("Incorrect command\n\r");
            Message_Pointer = Message;
            strcpy(CommandBuffer,"STATUS"); 

        }
        Message_Pointer=Message;        
    }
    return;
}



/* ** TransmitMessage
 *
 *  FILENAME: 
 *
 *  PARAMETERS:
 *
 *  DESCRIPTION: Transmits a complete message. Exits when last byte sent and
 *				 SCI1 available for another message
 *
 *  RETURNS:
 *
 */
void TransmitMessage(char *Message)
	{
	volatile char temp;
	
	temp =  SCIS1;
	while(*Message != NULL_STRING)
		{
		 SCIDRL = *Message;
		while ( SCIS1_TC != 1)   {}  //Loop until byte sent
		temp =  SCIS1;				//Read byte to  clear tc flag
		Message++;
		}
	}


/*
 ** EchoByte
 *
 *  FILENAME: 
 *
 *  PARAMETERS:
 *
 *  DESCRIPTION: Echo byte to serial port
 *
 *  RETURNS:
 *
 */
 void EchoByte(char *Message)
	{
	volatile char temp;
	
	temp =  SCIS1;
	 SCIDRL = *Message ;
	while ( SCIS1_TC != 1)   {}  //Loop until byte sent
	temp =  SCIS1;				//Read byte to  clear tc flag
	}




/*
 ** DisplayStatus
 *
 *  FILENAME: 
 *
 *  PARAMETERS:
 *
 *  DESCRIPTION: Send screen update to serial port  
 *
 *  RETURNS:
 *
 */

void DisplayStatus(void)
{
    char Display_Buffer[8];               /* Array used for displaying numbers */

    if (VerboseMode == VERBOSE_ON)
    {

        TransmitMessage("\f");
        TransmitMessage ("=========TANGO3 MONITOR V1.2 (c)Freescale 2005=========\n\r");	   
       
        TransmitMessage ("Pins\n\r");
        TransmitMessage ("----\n\r");

        TransmitMessage ("DATA     ");
        if (Data != 2)
        {
            sprintf(Display_Buffer, "%d\n\r", Data);
            TransmitMessage(Display_Buffer);
        }
        else
        {
            TransmitMessage("Z\n\r");
        }
        
        TransmitMessage ("MODE     ");
        if (Mode != 2)
        {
            sprintf(Display_Buffer, "%d\n\r", Mode);
            TransmitMessage(Display_Buffer);
        }
        else
        {
            TransmitMessage("Z\n\r");
        }

        TransmitMessage ("ENABLE   ");
        if (Enable !=2)
        {
            sprintf(Display_Buffer, "%d\n\r", Enable);
            TransmitMessage(Display_Buffer);
        }
        else
        {
            TransmitMessage("Z\n\r");
        }    

        TransmitMessage ("PA       ");
        if (Pa != 2)
        {
            sprintf(Display_Buffer, "%d\n\r", Pa);
            TransmitMessage(Display_Buffer);
        }
        else
        {
             TransmitMessage("Z\n\r");
        }

        TransmitMessage ("\n\r");
        TransmitMessage ("Parameters\n\r");
        TransmitMessage ("----------\n\r");

        TransmitMessage ("DATARATE   ");
        sprintf(Display_Buffer, "%d\n\r", DataRate);
        TransmitMessage(Display_Buffer);
        TransmitMessage ("\n\r");
    }
    else
    {
        TransmitMessage("\f");
        TransmitMessage ("PINS=");
         if (Data != 2)
        {
            sprintf(Display_Buffer, "%d", Data);
            TransmitMessage(Display_Buffer);
        }
        else
        {
            TransmitMessage("Z");
        }

 
        if (Mode != 2)
        {
            sprintf(Display_Buffer, "%d", Mode);
            TransmitMessage(Display_Buffer);
        }
        else
        {
            TransmitMessage("Z");
        }

        if (Enable !=2)
        {
            sprintf(Display_Buffer, "%d", Enable);
            TransmitMessage(Display_Buffer);
        }
        else
        {
            TransmitMessage("Z");
        }    

        if (Pa != 2)
        {
            sprintf(Display_Buffer, "%d", Pa);
            TransmitMessage(Display_Buffer);
        }
        else
        {
             TransmitMessage("Z");
        }

        TransmitMessage(" ");  
    }

}


/*
 ** DisplayHelp() 
 *
 *  FILENAME: 
 *
 *  PARAMETERS:
 *
 *  DESCRIPTION: Sends text for HELP command to serial port  
 *
 *  RETURNS:
 *
 */
void DisplayHelp(void)
{
//       	   DisplayStatus();
    	   TransmitMessage ("COMMAND LIST \n\r");
    	   TransmitMessage ("============ \n\r");
    	   TransmitMessage ("HELP           :Display list of commands \n\r");
    	   TransmitMessage ("STATUS         :Displays status of pins and parameters \n\r");
    	   TransmitMessage ("DATA x         :Set DATA pin to 1,0 or Z \n\r");
    	   TransmitMessage ("MODE x         :Set MODE pin to 1,0 or Z \n\r"); 
    	   TransmitMessage ("ENABLE x       :Set ENABLE pin to 1,0 or Z \n\r");
    	   TransmitMessage ("PA x           :Set ENABLEPA pin to 1,0 or Z \n\r");
    	   TransmitMessage ("DATARATE x     :Set Data Rate (500 - 10600) \n\r");
    	   TransmitMessage ("SEND x         :Send message (Format: P1010...E) \n\r");
    	   TransmitMessage ("VERBOSE ON/OFF :Enable/disable Verbose mode \n\r");
    	   TransmitMessage ("BAUD x         :Set baud rate to 9600,19200, 38400  \n\r");
         TransmitMessage ("TXSQUARE x     :Transmit square wave (x=period in us)\n\r");  
    	   
}



/*
 ** Main
 *
 *  FILENAME: 
 *
 *  PARAMETERS:
 *
 *  DESCRIPTION: Main program loop  
 *
 *  RETURNS:
 *
 */

void main(void) {
    SOPT= 3;             /* Disable watchdog, enable reset pin, enable debug pin */

    DisableInterrupts;

    SCI1Setup(BAUD_9600);

    VerboseMode = VERBOSE_ON;
     
    Data = Mode = Enable = Pa = 0;  /* Zero all pins */
 
    DataRate = 1000;                   
    
    TANGO_DATA = 0;                 
    TANGO_DATA_DDR = 1;             /* Set DATA pin to 0 */
    
    TANGO_MODE = 0;
    TANGO_MODE_DDR = 1;             /* Set MODE pin to 0 */
    
    TANGO_ENABLE = 0;
    TANGO_ENABLE_DDR = 1;           /* Set ENABLE pin to 0 */

    TANGO_ENABLE_PA = 0;
    TANGO_ENABLE_PA_DDR = 1;         /* Set PA pin to 0 */ 

    Message_Pointer=Message;        
   
    DisplayStatus();
    TransmitMessage("OK\n\n\r");    


    for(;;)
    {  
        if (SCIS1_RDRF == 1)        /* if a byte received, go to SCI1Rx */
        {
            SCI1Rx();
        }
    }

}
